@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: CloudServices.py 1208 2021-08-22 04:58:20Z Casey $
+# $Id: CloudServices.py 1232 2021-09-06 03:01:02Z Casey $
 #
 # Copyright (c) 2021 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Casey $
-# $Date: 2021-08-22 12:58:20 +0800 (Sun, 22 Aug 2021) $
-# $Revision: 1208 $
+# $Date: 2021-09-06 11:01:02 +0800 (Mon, 06 Sep 2021) $
+# $Revision: 1232 $
 
 import json
 import socket
@@ -49,7 +49,7 @@ class BaseServices(object):
     
     name = "Base"
 
-    def register(self, managerEmail, ifttt, companyName, projectName, server, domain, aliasDomainList=None):
+    def register(self, managerEmail, ifttt, companyName, projectName, server, domain, aliasDomainList=None, deleteDnsAndHealthchecks=False):
         return {
             
         }
@@ -59,7 +59,7 @@ class CloudflareService(BaseServices):
 
     name = "Cloudflare DNS"
 
-    def register(self, managerEmail, ifttt, companyName, projectName, server, domain, aliasDomainList=None):
+    def register(self, managerEmail, ifttt, companyName, projectName, server, domain, aliasDomainList=None, deleteDnsAndHealthchecks=False):
         # cf
         cf = Cloudflare(CLOUDFLARE_EMAIL, CLOUDFLARE_API_KEY)
         subdomain = tldextract.extract(domain).subdomain
@@ -92,6 +92,7 @@ class CloudflareService(BaseServices):
         # check dns 
         if ip and zoneID:
             finalResult = []
+            finalDeleteResult = []
             for domain in domains:
                 result = cf.dns_records(zoneID, domain).get('result')
                 if not result:
@@ -103,22 +104,32 @@ class CloudflareService(BaseServices):
                     result = result[0]
                 else:
                     result = result[0]
-                    # update
-                    result = cf.update_record(zoneID, result["id"], domain, result['ttl'], ip, result['proxied'])
-                    result = result["result"]
+                    if deleteDnsAndHealthchecks: # delete
+                        result = cf.delete_record(zoneID, result["id"], domain, result['ttl'], ip, result['proxied'])
+                        result = result["result"]
+                        finalDeleteResult.append(domain)
+                    else: # update
+                        result = cf.update_record(zoneID, result["id"], domain, result['ttl'], ip, result['proxied'])
+                        result = result["result"]
 
                 finalResult.append(result)
 
-            name = ''
-            for result in finalResult:
-                name += f'{result.get("name")}, '
+            if finalDeleteResult:
+                deletedDomains = ''
+                for domain in finalDeleteResult:
+                    deletedDomains += f'{domain}, '
+                return {'dns records have been deleted': deletedDomains}
+            else:
+                name = ''
+                for result in finalResult:
+                    name += f'{result.get("name")}, '
 
-            return {
-                'zone name': finalResult[0].get("zone_name"), 
-                'name': name, 
-                'type': finalResult[0].get("type"), 
-                'content': finalResult[0].get("content")
-            }
+                return {
+                    'zone name': finalResult[0].get("zone_name"), 
+                    'name': name, 
+                    'type': finalResult[0].get("type"), 
+                    'content': finalResult[0].get("content")
+                }
             
         raise RuntimeError("Can't get ip of server and zoneID: %s" % server)
 
@@ -378,7 +389,7 @@ class HealthchecksService(BaseServices):
         return hchkAPIKey, integrations
         
 
-    def register(self, managerEmail, ifttt, companyName, projectName, server, domain, aliasDomainList=None):
+    def register(self, managerEmail, ifttt, companyName, projectName, server, domain, aliasDomainList=None, deleteDnsAndHealthchecks=False):
         # connect 
         browser = self.loginHealthchecks()
        
@@ -472,7 +483,7 @@ class SentryService(BaseServices):
         browser["email"] = managerEmail
         browser.submit_selected()
 
-    def register(self, managerEmail, ifttt, companyName, projectName, server, domain, aliasDomainList=None):
+    def register(self, managerEmail, ifttt, companyName, projectName, server, domain, aliasDomainList=None, deleteDnsAndHealthchecks=False):
         # connect 
         browser = self.loginSentry()
         
